diff -urbB org/rdnzl-0.12.2/arrays.lisp patched/rdnzl-0.12.2/arrays.lisp
--- org/rdnzl-0.12.2/arrays.lisp	2008-02-14 11:33:51.000000000 +0100
+++ patched/rdnzl-0.12.2/arrays.lisp	2009-11-10 09:54:56.000000000 +0100
@@ -116,4 +116,22 @@
     (integer-to-enum
      (apply #'logior (mapcar #'enum-to-integer enums)) type-name)))
 
+(defmacro do-rdnzl-collection ((var collection-form &optional result) &body body)
+  "COLLECTION-FORM should be a form which evaluates to a CONTAINER
+structure wrapping a .NET collection.  BODY will be evaluated
+with VAR bound to each element of this collection \(as a CONTAINER) in
+turn.  Finally, the result of evaluating the form RESULT is returned."
+  (with-unique-names (collection enumerator)
+    `(let* ((,collection ,collection-form)
+            (,enumerator [GetEnumerator ,collection])
+            (,var (progn 
+                    [Reset ,enumerator]
+                    (and [MoveNext ,enumerator]
+                         [%Current ,enumerator]))))
+       (loop while ,var
+             do (progn
+                  ,@body
+                  (setq ,var (and [MoveNext ,enumerator] [%Current ,enumerator]))))
+       ,result)))
+
 (disable-rdnzl-syntax)
diff -urbB org/rdnzl-0.12.2/doc/index.html patched/rdnzl-0.12.2/doc/index.html
--- org/rdnzl-0.12.2/doc/index.html	2008-03-25 18:06:25.000000000 +0100
+++ patched/rdnzl-0.12.2/doc/index.html	2009-11-10 11:16:26.000000000 +0100
@@ -84,6 +84,7 @@
       <li><a href="#integer-to-enum"><code>integer-to-enum</code></a>
       <li><a href="#enum-to-integer"><code>enum-to-integer</code></a>
       <li><a href="#or-enums"><code>or-enums</code></a>
+      <li><a href="#do-rdnzl-collection"><code>do-rdnzl-collection</code></a>
     </ol>
     <li><a href="#exceptions">Handling of .NET exceptions</a>
     <ol>
@@ -766,6 +767,16 @@
 each element of this array in turn.  Finally, the result of evaluating
 the form <code><i>result</i></code> is returned.
 </blockquote>
+<p><br>[Macro]
+<br><a class=none name="do-rdnzl-collection"><b>do-rdnzl-collection</b> <i> (var collection-form <tt>&amp;optional</tt> result) <tt>&amp;body</tt> body </i> =&gt; <i> value*</i></a>
+
+
+<blockquote><br>
+<code><i>collection-form</i></code> should be a form which evaluates to a <a href="#objects">container</a> wrapping a
+.NET collection.  The <code><i>body</i></code> will be evaluated with <code><i>var</i></code> bound to
+each element of this collection in turn.  Finally, the result of evaluating
+the form <code><i>result</i></code> is returned.
+</blockquote>
 
 
 <p><br>[Function]
@@ -891,8 +902,11 @@
 
 <blockquote><br>
 Loads and returns the assembly with the name <code><i>name</i></code> (a string), uses the
-static .NET method <code>System.Reflection.Assembly::LoadWithPartialName</code>
+static .NET method <code>System.Reflection.Assembly::Load</code>
 internally.
+
+<p>Note: this method previously used LoadWithPartialName, which would silently fail (return null)
+in case of errors. The new implementation will cause an exception to be thrown instead of returning null.
 </blockquote>
 
 
Only in patched/rdnzl-0.12.2/doc: index.html~
diff -urbB org/rdnzl-0.12.2/import.lisp patched/rdnzl-0.12.2/import.lisp
--- org/rdnzl-0.12.2/import.lisp	2008-02-14 11:33:51.000000000 +0100
+++ patched/rdnzl-0.12.2/import.lisp	2009-11-10 09:57:36.000000000 +0100
@@ -95,8 +95,11 @@
          
 (defun load-assembly (name)
   "Loads and returns the assembly with the name NAME \(a string), uses
-LoadWithPartialName."
-  [System.Reflection.Assembly.LoadWithPartialName name])
+Load."
+  (let ((assembly-name (new "System.Reflection.AssemblyName")))
+    (setf [%Name assembly-name] name)
+    [System.Reflection.Assembly.Load assembly-name]))
+
 
 (defun import-assembly (assembly)
   "Imports all public types of the assembly ASSEMBLY \(a string or a
Only in patched/rdnzl-0.12.2: rdnzl-test.lisp
